## dbt-adapters 1.3.2 - July 02, 2024

### Under the Hood

* Fix query timer resolution ([#246](https://github.com/dbt-labs/dbt-adapters/issues/246))
* Add optional release_connection parameter to connection_named method ([#247](https://github.com/dbt-labs/dbt-adapters/issues/247))
